/*
 * Copyright 2009-2011 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.unitesk.reqcoverage.eclipse.wizards;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.eclipse.jface.dialogs.IDialogPage;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.List;

import com.unitesk.requality.eclipse.wizards.ITestGenWizard;

public class SelectTestTypePage extends WizardPage {
   private List list;
   /**
    * Constructor for SampleNewWizardPage.
    * 
    * @param pageName
    */
   public ITestGenWizard getTestWizard(){
	   return (ITestGenWizard)getWizard();
   }
   public SelectTestTypePage( ISelection selection, Map<String, Map<String, String>> map) {
      super( "selectTestGenerator" );
      setPageComplete(false);
      setTitle( "Select generator" );
      setDescription( "Select new test generator." );
	  Map<String, String> storedMap = new HashMap<String, String>();
	  for(String s:map.keySet())
		   storedMap.put(s, map.get(s).get("name"));
      setAvailableMap(storedMap);
   }
   
   /**
    * @see IDialogPage#createControl(Composite)
    */
   public void createControl( Composite parent ) {
      Composite container= new Composite( parent, SWT.NULL );
      GridLayout layout= new GridLayout();
      container.setLayout( layout );
      layout.numColumns= 1;
      layout.verticalSpacing= 9;
      Label label= new Label( container, SWT.NULL );
      label.setText( "&New Test Generators:" );
      
      list = new List(container, SWT.SINGLE);
      list.setLayoutData(new GridData(GridData.FILL_BOTH));
      list.addSelectionListener(new SelectionListener() {
		@Override
		public void widgetSelected(SelectionEvent e) {
			selectedId = null;
			if(list.getSelectionCount() > 0)
				selectedId = (String) storedMap.keySet().toArray()[list.getSelectionIndex()];
			((NewTestWizard)getWizard()).setSelectedId(selectedId);
			updateStatus(null);
		}
		@Override
		public void widgetDefaultSelected(SelectionEvent e) {
		}
      });
      for(String s : storedMap.keySet())
    	  list.add(storedMap.get(s));
 	  selectedId = null;

      setControl( container );
      updateStatus(null);
   }

   private String selectedId;
   
   private void updateStatus( String message ) {
      setErrorMessage( message );
      setPageComplete( message == null && selectedId != null);
   }
   
   private Map<String, String> storedMap;
   
   public void setAvailableMap(Map<String, String> set){
	   storedMap = set;
	   if(list != null){
		   list.removeAll();
	   		for(String s : set.keySet())
	   			list.add(set.get(s));
	   		selectedId = null;
   		}
   }
   public void updateSettings() {
	   Map<String,Map<String,String>> map = ((NewTestWizard)getWizard()).getAvailableMap();
	   Map<String, String> storedMap = new HashMap<String, String>();
	   for(String s:map.keySet())
		   storedMap.put(s, map.get(s).get("name"));
	   setAvailableMap(storedMap);
   }
}